

  // Auto generated
  // Adds public versions for event handlers to be called from 
  // JS implementation of these event handlers.
  
  // include header:
  #include "qquickview_base.h"
  //#include "qquickview_wrapper.h"
  //#include "header_cpp.h"
    
    #ifdef QT_QUICK_LIB
    #endif
  